@@ -1,19 +1,14 @@
 #' Mock functions in a package.
 #'
 #' @description
-#' `r lifecycle::badge("superseded")`
-#'
-#' `with_mock()` and `local_mock()` are superseded in favour of
-#' [with_mocked_bindings()] and [local_mocked_bindings()].
-#'
-#' These works by using some C code to temporarily modify the mocked function
-#' _in place_. This is abusive of R's internals, which makes it dangerous, and
-#' no longer recommended.
-#'
-#' @section 3rd edition:
 #' `r lifecycle::badge("deprecated")`
 #'
-#' `with_mock()` and `local_mock()` are deprecated in the third edition.
+#' `with_mock()` and `local_mock()` are deprecated in favour of
+#' [with_mocked_bindings()] and [local_mocked_bindings()].
+#'
+#' These functions worked by using some C code to temporarily modify the mocked
+#' function _in place_. This was an abuse of R's internals and it is no longer
+#' permitted.
 #'
 #' @param ... named parameters redefine mocked functions, unnamed parameters
 #'   will be evaluated after mocking the functions
@@ -26,7 +21,7 @@
 #' @return The result of the last unnamed parameter
 #' @export
 with_mock <- function(..., .env = topenv()) {
-  edition_deprecate(3, "with_mock()", "Please use with_mocked_bindings() instead")
+  lifecycle::deprecate_warn("3.3.0", "with_mock()", "with_mocked_bindings()")
 
   dots <- eval(substitute(alist(...)))
   mock_qual_names <- names(dots)
@@ -61,7 +56,7 @@ with_mock <- function(..., .env = topenv()) {
 #' @export
 #' @rdname with_mock
 local_mock <- function(..., .env = topenv(), .local_envir = parent.frame()) {
-  edition_deprecate(3, "local_mock()", "Please use local_mocked_bindings() instead")
+  lifecycle::deprecate_warn("3.3.0", "local_mock()", "local_mocked_bindings()")
 
   mocks <- extract_mocks(list(...), .env = .env)
   on_exit <- bquote(
