@@ -1,6 +1,3 @@
-#' @include reporter.R
-NULL
-
 #' Multi reporter: combine several reporters in one.
 #'
 #' This reporter is useful to use several reporters at the same time, e.g.
@@ -15,12 +12,16 @@ MultiReporter <- R6::R6Class("MultiReporter",
 
     initialize = function(reporters = list()) {
       super$initialize()
+      self$capabilities$parallel_support <- TRUE
       self$reporters <- reporters
     },
 
     start_reporter = function() {
       o_apply(self$reporters, "start_reporter")
     },
+    start_file = function(filename) {
+      o_apply(self$reporters, "start_file", filename)
+    },
     start_context = function(context) {
       o_apply(self$reporters, "start_context", context)
     },
@@ -38,10 +39,21 @@ MultiReporter <- R6::R6Class("MultiReporter",
     },
     end_reporter = function() {
       o_apply(self$reporters, "end_reporter")
+    },
+    end_file = function() {
+      o_apply(self$reporters, "end_file")
+    },
+    update = function() {
+      o_apply(self$reporters, "update")
     }
   )
 )
 
 o_apply <- function(objects, method, ...) {
-  lapply(objects, function(x) x[[method]](...))
+  x <- NULL # silence check note
+  f <- new_function(exprs(x = ), expr(
+    `$`(x, !!method)(...)
+  ))
+
+  lapply(objects, f)
 }
