@@ -4,52 +4,19 @@ magrittr::`%>%`
 
 null <- function(...) invisible()
 
-klass <- function(x) paste(class(x), collapse = "/")
-
-# Tools for finding srcrefs -----------------------------------------------
-
-find_first_srcref <- function(start) {
-  calls <- sys.calls()
-  calls <- calls[seq2(start, length(calls))]
-
-  for (call in calls) {
-    srcref <- attr(call, "srcref")
-    if (!is.null(srcref)) {
-      return(srcref)
-    }
-  }
-  NULL
-}
-
 escape_regex <- function(x) {
   chars <- c("*", ".", "?", "^", "+", "$", "|", "(", ")", "[", "]", "{", "}", "\\")
   gsub(paste0("([\\", paste0(collapse = "\\", chars), "])"), "\\\\\\1", x, perl = TRUE)
 }
 
-# For R 3.1
-dir.exists <- function(paths) {
-  file.exists(paths) & file.info(paths)$isdir
-}
-
 maybe_restart <- function(restart) {
   if (!is.null(findRestart(restart))) {
     invokeRestart(restart)
   }
 }
 
-# Backport for R 3.2
-strrep <- function(x, times) {
-  x = as.character(x)
-  if (length(x) == 0L)
-    return(x)
-  unlist(.mapply(function(x, times) {
-    if (is.na(x) || is.na(times))
-      return(NA_character_)
-    if (times <= 0L)
-      return("")
-    paste0(replicate(times, x), collapse = "")
-  }, list(x = x, times = times), MoreArgs = list()), use.names = FALSE)
-}
+# Backport for R < 4.0
+deparse1 <- function(expr, ...) paste(deparse(expr, ...), collapse = "\n")
 
 can_entrace <- function(cnd) {
   !inherits(cnd, "Throwable")
@@ -95,17 +62,6 @@ rstudio_tickle <- function() {
   rstudioapi::executeCommand("refreshFiles")
 }
 
-check_installed <- function(pkg, fun) {
-  if (is_installed(pkg)) {
-    return()
-  }
-
-  abort(c(
-    paste0("The ", pkg, " package must be installed in order to use `", fun, "`"),
-    i = paste0("Do you need to run `install.packages('", pkg, "')`?")
-  ))
-}
-
 first_upper <- function(x) {
   substr(x, 1, 1) <- toupper(substr(x, 1, 1))
   x
@@ -116,5 +72,19 @@ in_rcmd_check <- function() {
 }
 
 map_chr <- function(.x, .f, ...) {
+  .f <- as_function(.f)
   vapply(.x, .f, FUN.VALUE = character(1), ...)
 }
+map_lgl <- function(.x, .f, ...) {
+  .f <- as_function(.f)
+  vapply(.x, .f, FUN.VALUE = logical(1), ...)
+}
+
+r_version <- function() paste0("R", getRversion()[, 1:2])
+
+# Waiting on https://github.com/r-lib/withr/pull/188
+local_tempfile1 <- function(lines, env = parent.frame()) {
+  path <- withr::local_tempfile(.local_envir = env)
+  writeLines(lines, path)
+  path
+}
