@@ -1,7 +1,7 @@
 test_that("test_examples works with installed packages", {
   local_edition(2)
 
-  local_mock(test_rd = identity)
+  local_mocked_bindings(test_rd = identity)
   expect_true(length(test_examples()) > 1)
 })
 
