@@ -1,5 +1,3 @@
-context("test-expectation")
-
 test_that("expectation contains failure message even when successful", {
   e <- expect(TRUE, "I failed")
   expect_equal(e$message, "I failed")
@@ -28,14 +26,23 @@ test_that("`expect()` and `exp_signal()` signal expectations", {
 })
 
 test_that("conditionMessage() is called during conversion", {
-  local_methods(conditionMessage.foobar = function(...) "dispatched")
+  local_bindings(
+    conditionMessage.foobar = function(...) "dispatched",
+    .env = global_env()
+  )
 
   wrn <- warning_cnd("foobar", message = "wrong")
   expect_identical(as.expectation(wrn)$message, "dispatched")
 
   err <- error_cnd("foobar", message = "wrong")
-  expect_identical(as.expectation(err)$message, "dispatched")
+  expect_match(as.expectation(err)$message, "Error: dispatched")
 
   err <- cnd(c("foobar", "skip"), message = "wrong")
   expect_identical(as.expectation(err)$message, "dispatched")
 })
+
+test_that("error message includes call", {
+  f <- function() stop("Error!")
+  cnd <- catch_cnd(f())
+  expect_equal(format(as.expectation(cnd)), "Error in `f()`: Error!")
+})
